@@ -14,24 +14,24 @@ def build_config() -> dict[str, str]:
     """
     return dict(
         # Python settings
-        python_version="3.13",
-        python_install_dir=r"/usr/local/lib/python3.13/site-packages/",
+        python_version="3.14",
+        python_install_dir=r"/usr/local/lib/python3.14/site-packages/",
         python_path=r"/usr/bin/python",
 
         # Package versions
         contourpy_version="1.3.3",
-        meson_version="1.8.2",
+        meson_version="1.10.0",
         mesonpy_version="0.18.0",
-        pybind11_version="3.0.0",
+        pybind11_version="3.0.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/startdir/src/contourpy/.mesonpy-5cqu_82w/lib/contourpy/util",
-        source_dir=r"/startdir/src/contourpy/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-89ftcclm/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/startdir/src/contourpy/.mesonpy-5cqu_82w/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-89ftcclm/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="15.1.1",
+        compiler_version="15.2.1",
         linker_id="ld.bfd",
         compile_command="c++",
 
